/*
 * Use SWI instruction.
 * See gdb/sim/arm/armemu.c:ARMul_Emulate32(),armos.c:ARMul_OSHandleSWI()
 * (case 0xf0:)
 * See gdb/sim/testsuite/sim/arm/hello.ms
 */

#define SWI_Exit  0x11
#define SWI_Open  0x66
#define SWI_Close 0x68
#define SWI_Write 0x69
#define SWI_Read  0x6a

#define SYSCALL_BY_SWI
#ifdef SYSCALL_BY_SWI
#define SWI(arg) swi (arg)
#else
#define TOPBITS_AL (14 << 28) /* condition code */
#define SWI(arg) .long (TOPBITS_AL | (0xf0 << 20) | (arg))
#endif

	.org	0x1af0

	.section .text

	.arm
	.globl	_start
	.type	_start, %function
_start:
_fname:	.string	"pass.txt"
	.byte	0
	.byte	0
	.byte	0
	.long	0

	.long	0	/* R4 */
	.long	0	/* R5 */
	.long	1f	/* LR */

1:	ldr	r0, _fname_addr
__open:
	/*
	 * Flags of open() exchanged by translate_open_mode[].
	 * See gdb/sim/arm/armos.c:SWIopen()
	 * Specify only O_RDONLY flag.
	 * (See gdb/sim/arm/armos.c:translate_open_mode[])
	 */
	mov	r1, #0
	SWI(SWI_Open)

__read:
	ldr	r1, _buffer_addr
	mov	r2, #32
	SWI(SWI_Read)

__write:
	mov	r0, #1
	ldr	r1, _buffer_addr
	mov	r2, #32
	SWI(SWI_Write)

__exit:
	mov	r0, #0
	SWI(SWI_Exit)
	mov	pc, lr

	.align 4
_fname_addr:
	.long	_fname
_buffer_addr:
	.long	_buffer
_buffer:
